# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_cache.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!azure/azure_microsoft_cache.proto\x12!oak9.tython.azure.microsoft_cache\x1a\x13shared/shared.proto\"\xcb\x02\n\x0fMicrosoft_Cache\x12\x37\n\x05redis\x18\x01 \x01(\x0b\x32(.oak9.tython.azure.microsoft_cache.Redis\x12S\n\x14redis_firewall_rules\x18\x02 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_cache.RedisFirewallRules\x12S\n\x14redis_linked_servers\x18\x03 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_cache.RedisLinkedServers\x12U\n\x15redis_patch_schedules\x18\x04 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_cache.RedisPatchSchedules\"\xc7\x02\n\x1fRedisPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12L\n\x10private_endpoint\x18\x03 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_cache.PrivateEndpoint\x12s\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_cache.PrivateLinkServiceConnectionState\x12\x1a\n\x12provisioning_state\x18\x05 \x01(\t\"b\n!PrivateLinkServiceConnectionState\x12\x18\n\x10\x61\x63tions_required\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1f\n\x0fPrivateEndpoint\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xa8\x01\n\x13RedisPatchSchedules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12J\n\x10schedule_entries\x18\x03 \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_cache.ScheduleEntry\"X\n\rScheduleEntry\x12\x13\n\x0b\x64\x61y_of_week\x18\x01 \x01(\t\x12\x1a\n\x12maintenance_window\x18\x02 \x01(\t\x12\x16\n\x0estart_hour_utc\x18\x03 \x01(\x05\"\xb4\x01\n\x12RedisLinkedServers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1d\n\x15linked_redis_cache_id\x18\x03 \x01(\t\x12#\n\x1blinked_redis_cache_location\x18\x04 \x01(\t\x12\x13\n\x0bserver_role\x18\x05 \x01(\t\"}\n\x12RedisFirewallRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x65nd_ip\x18\x03 \x01(\t\x12\x10\n\x08start_ip\x18\x04 \x01(\t\"\xad\x07\n\x05Redis\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x08identity\x18\x02 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_cache.ManagedServiceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1b\n\x13\x65nable_non_ssl_port\x18\x05 \x01(\x08\x12\x1b\n\x13minimum_tls_version\x18\x06 \x01(\t\x12\x1d\n\x15public_network_access\x18\x07 \x01(\t\x12g\n\x13redis_configuration\x18\x08 \x01(\x0b\x32J.oak9.tython.azure.microsoft_cache.RedisCommonPropertiesRedisConfiguration\x12\x15\n\rredis_version\x18\t \x01(\t\x12\x1b\n\x13replicas_per_master\x18\n \x01(\x05\x12\x1c\n\x14replicas_per_primary\x18\x0b \x01(\x05\x12\x13\n\x0bshard_count\x18\x0c \x01(\x05\x12\x33\n\x03sku\x18\r \x01(\x0b\x32&.oak9.tython.azure.microsoft_cache.Sku\x12\x11\n\tstatic_ip\x18\x0e \x01(\t\x12\x11\n\tsubnet_id\x18\x0f \x01(\t\x12U\n\x0ftenant_settings\x18\x10 \x03(\x0b\x32<.oak9.tython.azure.microsoft_cache.Redis.TenantSettingsEntry\x12@\n\x04tags\x18\x11 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_cache.Redis.TagsEntry\x12\r\n\x05zones\x18\x12 \x03(\t\x12n\n\"redis_private_endpoint_connections\x18\x13 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_cache.RedisPrivateEndpointConnections\x1a\x35\n\x13TenantSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\x03Sku\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x05\x12\x0e\n\x06\x66\x61mily\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xbe\x04\n\'RedisCommonPropertiesRedisConfiguration\x12\x83\x01\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32\x64.oak9.tython.azure.microsoft_cache.RedisCommonPropertiesRedisConfiguration.AdditionalPropertiesEntry\x12\'\n\x1f\x61of_storage_connection_string_0\x18\x02 \x01(\t\x12\'\n\x1f\x61of_storage_connection_string_1\x18\x03 \x01(\t\x12\'\n\x1fmaxfragmentationmemory_reserved\x18\x04 \x01(\t\x12\x17\n\x0fmaxmemory_delta\x18\x05 \x01(\t\x12\x18\n\x10maxmemory_policy\x18\x06 \x01(\t\x12\x1a\n\x12maxmemory_reserved\x18\x07 \x01(\t\x12\x1a\n\x12rdb_backup_enabled\x18\x08 \x01(\t\x12\x1c\n\x14rdb_backup_frequency\x18\t \x01(\t\x12%\n\x1drdb_backup_max_snapshot_count\x18\n \x01(\t\x12%\n\x1drdb_storage_connection_string\x18\x0b \x01(\t\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xde\x01\n\x16ManagedServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12w\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32U.oak9.tython.azure.microsoft_cache.ManagedServiceIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_cache_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REDIS_TENANTSETTINGSENTRY._options = None
  _REDIS_TENANTSETTINGSENTRY._serialized_options = b'8\001'
  _REDIS_TAGSENTRY._options = None
  _REDIS_TAGSENTRY._serialized_options = b'8\001'
  _REDISCOMMONPROPERTIESREDISCONFIGURATION_ADDITIONALPROPERTIESENTRY._options = None
  _REDISCOMMONPROPERTIESREDISCONFIGURATION_ADDITIONALPROPERTIESENTRY._serialized_options = b'8\001'
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_CACHE._serialized_start=94
  _MICROSOFT_CACHE._serialized_end=425
  _REDISPRIVATEENDPOINTCONNECTIONS._serialized_start=428
  _REDISPRIVATEENDPOINTCONNECTIONS._serialized_end=755
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=757
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=855
  _PRIVATEENDPOINT._serialized_start=857
  _PRIVATEENDPOINT._serialized_end=888
  _REDISPATCHSCHEDULES._serialized_start=891
  _REDISPATCHSCHEDULES._serialized_end=1059
  _SCHEDULEENTRY._serialized_start=1061
  _SCHEDULEENTRY._serialized_end=1149
  _REDISLINKEDSERVERS._serialized_start=1152
  _REDISLINKEDSERVERS._serialized_end=1332
  _REDISFIREWALLRULES._serialized_start=1334
  _REDISFIREWALLRULES._serialized_end=1459
  _REDIS._serialized_start=1462
  _REDIS._serialized_end=2403
  _REDIS_TENANTSETTINGSENTRY._serialized_start=2305
  _REDIS_TENANTSETTINGSENTRY._serialized_end=2358
  _REDIS_TAGSENTRY._serialized_start=2360
  _REDIS_TAGSENTRY._serialized_end=2403
  _SKU._serialized_start=2405
  _SKU._serialized_end=2458
  _REDISCOMMONPROPERTIESREDISCONFIGURATION._serialized_start=2461
  _REDISCOMMONPROPERTIESREDISCONFIGURATION._serialized_end=3035
  _REDISCOMMONPROPERTIESREDISCONFIGURATION_ADDITIONALPROPERTIESENTRY._serialized_start=2976
  _REDISCOMMONPROPERTIESREDISCONFIGURATION_ADDITIONALPROPERTIESENTRY._serialized_end=3035
  _MANAGEDSERVICEIDENTITY._serialized_start=3038
  _MANAGEDSERVICEIDENTITY._serialized_end=3260
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=3199
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=3260
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_interconnect.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"gcp/gcp_compute_interconnect.proto\x12$oak9.tython.gcp.compute_interconnect\x1a\x13shared/shared.proto\"X\n&ComputeInterconnectAttachmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x8d\x07\n\x1d\x43omputeInterconnectAttachment\x12\x15\n\radmin_enabled\x18\x01 \x01(\x08\x12\x11\n\tbandwidth\x18\x02 \x01(\t\x12\x19\n\x11\x63\x61ndidate_subnets\x18\x03 \x03(\t\x12\x1f\n\x17\x63loud_router_ip_address\x18\x04 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x05 \x01(\t\x12\"\n\x1a\x63ustomer_router_ip_address\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12 \n\x18\x65\x64ge_availability_domain\x18\x08 \x01(\t\x12\x12\n\nencryption\x18\t \x01(\t\x12\x1b\n\x13google_reference_id\x18\n \x01(\t\x12\n\n\x02id\x18\x0b \x01(\t\x12\x14\n\x0cinterconnect\x18\x0c \x01(\t\x12 \n\x18ipsec_internal_addresses\x18\r \x03(\t\x12\x0b\n\x03mtu\x18\x0e \x01(\t\x12\x0c\n\x04name\x18\x0f \x01(\t\x12\x13\n\x0bpairing_key\x18\x10 \x01(\t\x12\x13\n\x0bpartner_asn\x18\x11 \x01(\t\x12\x83\x01\n\x19private_interconnect_info\x18\x12 \x03(\x0b\x32`.oak9.tython.gcp.compute_interconnect.ComputeInterconnectAttachment.PrivateInterconnectInfoEntry\x12\x0f\n\x07project\x18\x13 \x01(\t\x12\x0e\n\x06region\x18\x14 \x01(\t\x12\x0e\n\x06router\x18\x15 \x01(\t\x12\x11\n\tself_link\x18\x16 \x01(\t\x12\r\n\x05state\x18\x17 \x01(\t\x12\x0c\n\x04type\x18\x18 \x01(\t\x12\x15\n\rvlan_tag8021q\x18\x19 \x01(\x01\x12^\n\x08timeouts\x18\x1a \x01(\x0b\x32L.oak9.tython.gcp.compute_interconnect.ComputeInterconnectAttachmentXTimeouts\x12\x37\n\rresource_info\x18\x1b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a>\n\x1cPrivateInterconnectInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_interconnect_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEINTERCONNECTATTACHMENT_PRIVATEINTERCONNECTINFOENTRY._options = None
  _COMPUTEINTERCONNECTATTACHMENT_PRIVATEINTERCONNECTINFOENTRY._serialized_options = b'8\001'
  _COMPUTEINTERCONNECTATTACHMENTXTIMEOUTS._serialized_start=97
  _COMPUTEINTERCONNECTATTACHMENTXTIMEOUTS._serialized_end=185
  _COMPUTEINTERCONNECTATTACHMENT._serialized_start=188
  _COMPUTEINTERCONNECTATTACHMENT._serialized_end=1097
  _COMPUTEINTERCONNECTATTACHMENT_PRIVATEINTERCONNECTINFOENTRY._serialized_start=1035
  _COMPUTEINTERCONNECTATTACHMENT_PRIVATEINTERCONNECTINFOENTRY._serialized_end=1097
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.resource.v1alpha1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8kubernetes/kubernetes_io.k8s.api.resource.v1alpha1.proto\x12%oak9.tython.k8s.api.resource.v1alpha1\x1a\x13shared/shared.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\xbe\x01\n\x10\x41llocationResult\x12\x45\n\x12\x61vailable_on_nodes\x18\x01 \x01(\x0b\x32).oak9.tython.k8s.api.core.v1.NodeSelector\x12\x17\n\x0fresource_handle\x18\x02 \x01(\t\x12\x11\n\tshareable\x18\x03 \x01(\x08\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcc\x02\n\rPodScheduling\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x46\n\x04spec\x18\x04 \x01(\x0b\x32\x38.oak9.tython.k8s.api.resource.v1alpha1.PodSchedulingSpec\x12J\n\x06status\x18\x05 \x01(\x0b\x32:.oak9.tython.k8s.api.resource.v1alpha1.PodSchedulingStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xff\x01\n\x11PodSchedulingList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x43\n\x05items\x18\x02 \x03(\x0b\x32\x34.oak9.tython.k8s.api.resource.v1alpha1.PodScheduling\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"|\n\x11PodSchedulingSpec\x12\x17\n\x0fpotential_nodes\x18\x01 \x03(\t\x12\x15\n\rselected_node\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xad\x01\n\x13PodSchedulingStatus\x12]\n\x0fresource_claims\x18\x01 \x03(\x0b\x32\x44.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimSchedulingStatus\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xcc\x02\n\rResourceClaim\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x46\n\x04spec\x18\x04 \x01(\x0b\x32\x38.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimSpec\x12J\n\x06status\x18\x05 \x01(\x0b\x32:.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x99\x01\n\x1eResourceClaimConsumerReference\x12\x11\n\tapi_group\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08resource\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xff\x01\n\x11ResourceClaimList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x43\n\x05items\x18\x02 \x03(\x0b\x32\x34.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaim\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8a\x01\n ResourceClaimParametersReference\x12\x11\n\tapi_group\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x80\x01\n\x1dResourceClaimSchedulingStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10unsuitable_nodes\x18\x02 \x03(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe3\x01\n\x11ResourceClaimSpec\x12\x17\n\x0f\x61llocation_mode\x18\x01 \x01(\t\x12_\n\x0eparameters_ref\x18\x02 \x01(\x0b\x32G.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimParametersReference\x12\x1b\n\x13resource_class_name\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xad\x02\n\x13ResourceClaimStatus\x12K\n\nallocation\x18\x01 \x01(\x0b\x32\x37.oak9.tython.k8s.api.resource.v1alpha1.AllocationResult\x12\x1e\n\x16\x64\x65\x61llocation_requested\x18\x02 \x01(\x08\x12\x13\n\x0b\x64river_name\x18\x03 \x01(\t\x12[\n\x0creserved_for\x18\x04 \x03(\x0b\x32\x45.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimConsumerReference\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x90\x02\n\x15ResourceClaimTemplate\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12N\n\x04spec\x18\x04 \x01(\x0b\x32@.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimTemplateSpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8f\x02\n\x19ResourceClaimTemplateList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12K\n\x05items\x18\x02 \x03(\x0b\x32<.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimTemplate\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe9\x01\n\x19ResourceClaimTemplateSpec\x12K\n\x08metadata\x18\x01 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x46\n\x04spec\x18\x02 \x01(\x0b\x32\x38.oak9.tython.k8s.api.resource.v1alpha1.ResourceClaimSpec\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf1\x02\n\rResourceClass\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x13\n\x0b\x64river_name\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12K\n\x08metadata\x18\x04 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12_\n\x0eparameters_ref\x18\x05 \x01(\x0b\x32G.oak9.tython.k8s.api.resource.v1alpha1.ResourceClassParametersReference\x12\x41\n\x0esuitable_nodes\x18\x06 \x01(\x0b\x32).oak9.tython.k8s.api.core.v1.NodeSelector\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xff\x01\n\x11ResourceClassList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x43\n\x05items\x18\x02 \x03(\x0b\x32\x34.oak9.tython.k8s.api.resource.v1alpha1.ResourceClass\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9d\x01\n ResourceClassParametersReference\x12\x11\n\tapi_group\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.resource.v1alpha1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ALLOCATIONRESULT._serialized_start=235
  _ALLOCATIONRESULT._serialized_end=425
  _PODSCHEDULING._serialized_start=428
  _PODSCHEDULING._serialized_end=760
  _PODSCHEDULINGLIST._serialized_start=763
  _PODSCHEDULINGLIST._serialized_end=1018
  _PODSCHEDULINGSPEC._serialized_start=1020
  _PODSCHEDULINGSPEC._serialized_end=1144
  _PODSCHEDULINGSTATUS._serialized_start=1147
  _PODSCHEDULINGSTATUS._serialized_end=1320
  _RESOURCECLAIM._serialized_start=1323
  _RESOURCECLAIM._serialized_end=1655
  _RESOURCECLAIMCONSUMERREFERENCE._serialized_start=1658
  _RESOURCECLAIMCONSUMERREFERENCE._serialized_end=1811
  _RESOURCECLAIMLIST._serialized_start=1814
  _RESOURCECLAIMLIST._serialized_end=2069
  _RESOURCECLAIMPARAMETERSREFERENCE._serialized_start=2072
  _RESOURCECLAIMPARAMETERSREFERENCE._serialized_end=2210
  _RESOURCECLAIMSCHEDULINGSTATUS._serialized_start=2213
  _RESOURCECLAIMSCHEDULINGSTATUS._serialized_end=2341
  _RESOURCECLAIMSPEC._serialized_start=2344
  _RESOURCECLAIMSPEC._serialized_end=2571
  _RESOURCECLAIMSTATUS._serialized_start=2574
  _RESOURCECLAIMSTATUS._serialized_end=2875
  _RESOURCECLAIMTEMPLATE._serialized_start=2878
  _RESOURCECLAIMTEMPLATE._serialized_end=3150
  _RESOURCECLAIMTEMPLATELIST._serialized_start=3153
  _RESOURCECLAIMTEMPLATELIST._serialized_end=3424
  _RESOURCECLAIMTEMPLATESPEC._serialized_start=3427
  _RESOURCECLAIMTEMPLATESPEC._serialized_end=3660
  _RESOURCECLASS._serialized_start=3663
  _RESOURCECLASS._serialized_end=4032
  _RESOURCECLASSLIST._serialized_start=4035
  _RESOURCECLASSLIST._serialized_end=4290
  _RESOURCECLASSPARAMETERSREFERENCE._serialized_start=4293
  _RESOURCECLASSPARAMETERSREFERENCE._serialized_end=4450
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_attached.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egcp/gcp_compute_attached.proto\x12 oak9.tython.gcp.compute_attached\x1a\x13shared/shared.proto\">\n\x1c\x43omputeAttachedDiskXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x8e\x02\n\x13\x43omputeAttachedDisk\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x0c\n\x04\x64isk\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08instance\x18\x04 \x01(\t\x12\x0c\n\x04mode\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04zone\x18\x07 \x01(\t\x12P\n\x08timeouts\x18\x08 \x01(\x0b\x32>.oak9.tython.gcp.compute_attached.ComputeAttachedDiskXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_attached_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEATTACHEDDISKXTIMEOUTS._serialized_start=89
  _COMPUTEATTACHEDDISKXTIMEOUTS._serialized_end=151
  _COMPUTEATTACHEDDISK._serialized_start=154
  _COMPUTEATTACHEDDISK._serialized_end=424
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeServiceAttachmentXConsumerAcceptLists(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_LIMIT_FIELD_NUMBER: builtins.int
    PROJECT_ID_OR_NUM_FIELD_NUMBER: builtins.int
    connection_limit: builtins.float
    project_id_or_num: builtins.str
    def __init__(
        self,
        *,
        connection_limit: builtins.float = ...,
        project_id_or_num: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_limit", b"connection_limit", "project_id_or_num", b"project_id_or_num"]) -> None: ...

global___ComputeServiceAttachmentXConsumerAcceptLists = ComputeServiceAttachmentXConsumerAcceptLists

@typing_extensions.final
class ComputeServiceAttachmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeServiceAttachmentXTimeouts = ComputeServiceAttachmentXTimeouts

@typing_extensions.final
class ComputeServiceAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ConnectedEndpointsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONNECTED_ENDPOINTS_FIELD_NUMBER: builtins.int
    CONNECTION_PREFERENCE_FIELD_NUMBER: builtins.int
    CONSUMER_REJECT_LISTS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DOMAIN_NAMES_FIELD_NUMBER: builtins.int
    ENABLE_PROXY_PROTOCOL_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAT_SUBNETS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TARGET_SERVICE_FIELD_NUMBER: builtins.int
    CONSUMER_ACCEPT_LISTS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def connected_endpoints(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    connection_preference: builtins.str
    @property
    def consumer_reject_lists(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    description: builtins.str
    @property
    def domain_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enable_proxy_protocol: builtins.bool
    fingerprint: builtins.str
    id: builtins.str
    name: builtins.str
    @property
    def nat_subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    target_service: builtins.str
    @property
    def consumer_accept_lists(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeServiceAttachmentXConsumerAcceptLists]: ...
    @property
    def timeouts(self) -> global___ComputeServiceAttachmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        connected_endpoints: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        connection_preference: builtins.str = ...,
        consumer_reject_lists: collections.abc.Iterable[builtins.str] | None = ...,
        description: builtins.str = ...,
        domain_names: collections.abc.Iterable[builtins.str] | None = ...,
        enable_proxy_protocol: builtins.bool = ...,
        fingerprint: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        nat_subnets: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        target_service: builtins.str = ...,
        consumer_accept_lists: collections.abc.Iterable[global___ComputeServiceAttachmentXConsumerAcceptLists] | None = ...,
        timeouts: global___ComputeServiceAttachmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connected_endpoints", b"connected_endpoints", "connection_preference", b"connection_preference", "consumer_accept_lists", b"consumer_accept_lists", "consumer_reject_lists", b"consumer_reject_lists", "description", b"description", "domain_names", b"domain_names", "enable_proxy_protocol", b"enable_proxy_protocol", "fingerprint", b"fingerprint", "id", b"id", "name", b"name", "nat_subnets", b"nat_subnets", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "target_service", b"target_service", "timeouts", b"timeouts"]) -> None: ...

global___ComputeServiceAttachment = ComputeServiceAttachment



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_backup.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61ws/aws_backup.proto\x12\x16oak9.tython.aws.backup\x1a\x13shared/shared.proto\"\x9e\x01\n\x1f\x42\x61\x63kupPlanLifecycleResourceType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x64\x65lete_after_days\x18\x02 \x01(\x01\x12\'\n\x1fmove_to_cold_storage_after_days\x18\x03 \x01(\x01\"\xcd\x01\n BackupPlanCopyActionResourceType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\tlifecycle\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.backup.BackupPlanLifecycleResourceType\x12$\n\x1c\x64\x65stination_backup_vault_arn\x18\x03 \x01(\t\"\xad\x04\n BackupPlanBackupRuleResourceType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19\x63ompletion_window_minutes\x18\x02 \x01(\x01\x12\x1b\n\x13schedule_expression\x18\x03 \x01(\t\x12l\n\x13recovery_point_tags\x18\x04 \x03(\x0b\x32O.oak9.tython.aws.backup.BackupPlanBackupRuleResourceType.RecoveryPointTagsEntry\x12N\n\x0c\x63opy_actions\x18\x05 \x03(\x0b\x32\x38.oak9.tython.aws.backup.BackupPlanCopyActionResourceType\x12J\n\tlifecycle\x18\x06 \x01(\x0b\x32\x37.oak9.tython.aws.backup.BackupPlanLifecycleResourceType\x12\x1b\n\x13target_backup_vault\x18\x07 \x01(\t\x12\x1c\n\x14start_window_minutes\x18\x08 \x01(\x01\x12\x11\n\trule_name\x18\t \x01(\t\x1a\x38\n\x16RecoveryPointTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc9\x01\n BackupPlanBackupPlanResourceType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x62\x61\x63kup_plan_name\x18\x02 \x01(\t\x12R\n\x10\x62\x61\x63kup_plan_rule\x18\x03 \x03(\x0b\x32\x38.oak9.tython.aws.backup.BackupPlanBackupRuleResourceType\"\x9d\x02\n\nBackupPlan\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x0b\x62\x61\x63kup_plan\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.backup.BackupPlanBackupPlanResourceType\x12P\n\x10\x62\x61\x63kup_plan_tags\x18\x03 \x03(\x0b\x32\x36.oak9.tython.aws.backup.BackupPlan.BackupPlanTagsEntry\x1a\x35\n\x13\x42\x61\x63kupPlanTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbf\x01\n\x06\x42\x61\x63kup\x12\x37\n\x0b\x62\x61\x63kup_plan\x18\x01 \x03(\x0b\x32\".oak9.tython.aws.backup.BackupPlan\x12\x41\n\x10\x62\x61\x63kup_selection\x18\x02 \x03(\x0b\x32\'.oak9.tython.aws.backup.BackupSelection\x12\x39\n\x0c\x62\x61\x63kup_vault\x18\x03 \x03(\x0b\x32#.oak9.tython.aws.backup.BackupVault\"\xa7\x01\n$BackupSelectionConditionResourceType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63ondition_value\x18\x02 \x01(\t\x12\x15\n\rcondition_key\x18\x03 \x01(\t\x12\x16\n\x0e\x63ondition_type\x18\x04 \x01(\t\"\xfa\x01\n*BackupSelectionBackupSelectionResourceType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x0clist_of_tags\x18\x02 \x03(\x0b\x32<.oak9.tython.aws.backup.BackupSelectionConditionResourceType\x12\x16\n\x0eselection_name\x18\x03 \x01(\t\x12\x14\n\x0ciam_role_arn\x18\x04 \x01(\t\x12\x11\n\tresources\x18\x05 \x03(\t\"\xc0\x01\n\x0f\x42\x61\x63kupSelection\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\\\n\x10\x62\x61\x63kup_selection\x18\x02 \x01(\x0b\x32\x42.oak9.tython.aws.backup.BackupSelectionBackupSelectionResourceType\x12\x16\n\x0e\x62\x61\x63kup_plan_id\x18\x03 \x01(\t\"\x90\x01\n!BackupVaultNotificationObjectType\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rsns_topic_arn\x18\x02 \x01(\t\x12\x1b\n\x13\x62\x61\x63kup_vault_events\x18\x03 \x03(\t\"\xdf\x03\n\x0b\x42\x61\x63kupVault\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x11\x62\x61\x63kup_vault_tags\x18\x02 \x03(\x0b\x32\x38.oak9.tython.aws.backup.BackupVault.BackupVaultTagsEntry\x12\x19\n\x11\x62\x61\x63kup_vault_name\x18\x03 \x01(\t\x12\x1a\n\x12\x65ncryption_key_arn\x18\x04 \x01(\t\x12P\n\rnotifications\x18\x05 \x01(\x0b\x32\x39.oak9.tython.aws.backup.BackupVaultNotificationObjectType\x12L\n\raccess_policy\x18\x06 \x03(\x0b\x32\x35.oak9.tython.aws.backup.BackupVault.AccessPolicyEntry\x1a\x36\n\x14\x42\x61\x63kupVaultTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11\x41\x63\x63\x65ssPolicyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_backup_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BACKUPPLANBACKUPRULERESOURCETYPE_RECOVERYPOINTTAGSENTRY._options = None
  _BACKUPPLANBACKUPRULERESOURCETYPE_RECOVERYPOINTTAGSENTRY._serialized_options = b'8\001'
  _BACKUPPLAN_BACKUPPLANTAGSENTRY._options = None
  _BACKUPPLAN_BACKUPPLANTAGSENTRY._serialized_options = b'8\001'
  _BACKUPVAULT_BACKUPVAULTTAGSENTRY._options = None
  _BACKUPVAULT_BACKUPVAULTTAGSENTRY._serialized_options = b'8\001'
  _BACKUPVAULT_ACCESSPOLICYENTRY._options = None
  _BACKUPVAULT_ACCESSPOLICYENTRY._serialized_options = b'8\001'
  _BACKUPPLANLIFECYCLERESOURCETYPE._serialized_start=70
  _BACKUPPLANLIFECYCLERESOURCETYPE._serialized_end=228
  _BACKUPPLANCOPYACTIONRESOURCETYPE._serialized_start=231
  _BACKUPPLANCOPYACTIONRESOURCETYPE._serialized_end=436
  _BACKUPPLANBACKUPRULERESOURCETYPE._serialized_start=439
  _BACKUPPLANBACKUPRULERESOURCETYPE._serialized_end=996
  _BACKUPPLANBACKUPRULERESOURCETYPE_RECOVERYPOINTTAGSENTRY._serialized_start=940
  _BACKUPPLANBACKUPRULERESOURCETYPE_RECOVERYPOINTTAGSENTRY._serialized_end=996
  _BACKUPPLANBACKUPPLANRESOURCETYPE._serialized_start=999
  _BACKUPPLANBACKUPPLANRESOURCETYPE._serialized_end=1200
  _BACKUPPLAN._serialized_start=1203
  _BACKUPPLAN._serialized_end=1488
  _BACKUPPLAN_BACKUPPLANTAGSENTRY._serialized_start=1435
  _BACKUPPLAN_BACKUPPLANTAGSENTRY._serialized_end=1488
  _BACKUP._serialized_start=1491
  _BACKUP._serialized_end=1682
  _BACKUPSELECTIONCONDITIONRESOURCETYPE._serialized_start=1685
  _BACKUPSELECTIONCONDITIONRESOURCETYPE._serialized_end=1852
  _BACKUPSELECTIONBACKUPSELECTIONRESOURCETYPE._serialized_start=1855
  _BACKUPSELECTIONBACKUPSELECTIONRESOURCETYPE._serialized_end=2105
  _BACKUPSELECTION._serialized_start=2108
  _BACKUPSELECTION._serialized_end=2300
  _BACKUPVAULTNOTIFICATIONOBJECTTYPE._serialized_start=2303
  _BACKUPVAULTNOTIFICATIONOBJECTTYPE._serialized_end=2447
  _BACKUPVAULT._serialized_start=2450
  _BACKUPVAULT._serialized_end=2929
  _BACKUPVAULT_BACKUPVAULTTAGSENTRY._serialized_start=2822
  _BACKUPVAULT_BACKUPVAULTTAGSENTRY._serialized_end=2876
  _BACKUPVAULT_ACCESSPOLICYENTRY._serialized_start=2878
  _BACKUPVAULT_ACCESSPOLICYENTRY._serialized_end=2929
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ec2_securitygroup.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61ws/aws_ec2_securitygroup.proto\x12!oak9.tython.aws.ec2_securitygroup\x1a\x13shared/shared.proto\"P\n\x13SecurityGroupEgress\x12\x39\n\x06\x65gress\x18\x01 \x01(\x0b\x32).oak9.tython.aws.ec2_securitygroup.Egress\"S\n\x14SecurityGroupIngress\x12;\n\x07ingress\x18\x01 \x01(\x0b\x32*.oak9.tython.aws.ec2_securitygroup.Ingress\"\xae\x03\n\rSecurityGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11group_description\x18\x02 \x01(\t\x12\x12\n\ngroup_name\x18\x03 \x01(\t\x12U\n\x15security_group_egress\x18\x04 \x03(\x0b\x32\x36.oak9.tython.aws.ec2_securitygroup.SecurityGroupEgress\x12W\n\x16security_group_ingress\x18\x05 \x03(\x0b\x32\x37.oak9.tython.aws.ec2_securitygroup.SecurityGroupIngress\x12H\n\x04tags\x18\x06 \x03(\x0b\x32:.oak9.tython.aws.ec2_securitygroup.SecurityGroup.TagsEntry\x12\x0e\n\x06vpc_id\x18\x07 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfe\x01\n\x06\x45gress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63idr_ip\x18\x02 \x01(\t\x12\x11\n\tcidr_ipv6\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\"\n\x1a\x64\x65stination_prefix_list_id\x18\x05 \x01(\t\x12%\n\x1d\x64\x65stination_security_group_id\x18\x06 \x01(\t\x12\x11\n\tfrom_port\x18\x07 \x01(\x05\x12\x13\n\x0bip_protocol\x18\x08 \x01(\t\x12\x0f\n\x07to_port\x18\t \x01(\x05\"\xc1\x02\n\x07Ingress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63idr_ip\x18\x02 \x01(\t\x12\x11\n\tcidr_ipv6\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x1d\n\x15source_prefix_list_id\x18\x05 \x01(\t\x12 \n\x18source_security_group_id\x18\x06 \x01(\t\x12\"\n\x1asource_security_group_name\x18\x07 \x01(\t\x12&\n\x1esource_security_group_owner_id\x18\x08 \x01(\t\x12\x11\n\tfrom_port\x18\t \x01(\x05\x12\x13\n\x0bip_protocol\x18\n \x01(\t\x12\x0f\n\x07to_port\x18\x0b \x01(\x05\"]\n\x11\x45\x43\x32_SecurityGroup\x12H\n\x0esecurity_group\x18\x01 \x01(\x0b\x32\x30.oak9.tython.aws.ec2_securitygroup.SecurityGroupb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ec2_securitygroup_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SECURITYGROUP_TAGSENTRY._options = None
  _SECURITYGROUP_TAGSENTRY._serialized_options = b'8\001'
  _SECURITYGROUPEGRESS._serialized_start=91
  _SECURITYGROUPEGRESS._serialized_end=171
  _SECURITYGROUPINGRESS._serialized_start=173
  _SECURITYGROUPINGRESS._serialized_end=256
  _SECURITYGROUP._serialized_start=259
  _SECURITYGROUP._serialized_end=689
  _SECURITYGROUP_TAGSENTRY._serialized_start=646
  _SECURITYGROUP_TAGSENTRY._serialized_end=689
  _EGRESS._serialized_start=692
  _EGRESS._serialized_end=946
  _INGRESS._serialized_start=949
  _INGRESS._serialized_end=1270
  _EC2_SECURITYGROUP._serialized_start=1272
  _EC2_SECURITYGROUP._serialized_end=1365
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class InstanceEbs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DELETE_ON_TERMINATION_FIELD_NUMBER: builtins.int
    ENCRYPTED_FIELD_NUMBER: builtins.int
    IOPS_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    VOLUME_SIZE_FIELD_NUMBER: builtins.int
    VOLUME_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    delete_on_termination: builtins.bool
    encrypted: builtins.bool
    iops: builtins.int
    kms_key_id: builtins.str
    snapshot_id: builtins.str
    volume_size: builtins.int
    volume_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        delete_on_termination: builtins.bool = ...,
        encrypted: builtins.bool = ...,
        iops: builtins.int = ...,
        kms_key_id: builtins.str = ...,
        snapshot_id: builtins.str = ...,
        volume_size: builtins.int = ...,
        volume_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_on_termination", b"delete_on_termination", "encrypted", b"encrypted", "iops", b"iops", "kms_key_id", b"kms_key_id", "resource_info", b"resource_info", "snapshot_id", b"snapshot_id", "volume_size", b"volume_size", "volume_type", b"volume_type"]) -> None: ...

global___InstanceEbs = InstanceEbs

@typing_extensions.final
class InstanceNoDevice(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___InstanceNoDevice = InstanceNoDevice

@typing_extensions.final
class InstanceBlockDeviceMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    EBS_FIELD_NUMBER: builtins.int
    NO_DEVICE_FIELD_NUMBER: builtins.int
    VIRTUAL_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    device_name: builtins.str
    @property
    def ebs(self) -> global___InstanceEbs: ...
    @property
    def no_device(self) -> global___InstanceNoDevice: ...
    virtual_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        device_name: builtins.str = ...,
        ebs: global___InstanceEbs | None = ...,
        no_device: global___InstanceNoDevice | None = ...,
        virtual_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ebs", b"ebs", "no_device", b"no_device", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_name", b"device_name", "ebs", b"ebs", "no_device", b"no_device", "resource_info", b"resource_info", "virtual_name", b"virtual_name"]) -> None: ...

global___InstanceBlockDeviceMapping = InstanceBlockDeviceMapping

@typing_extensions.final
class InstanceCpuOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CORE_COUNT_FIELD_NUMBER: builtins.int
    THREADS_PER_CORE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    core_count: builtins.int
    threads_per_core: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        core_count: builtins.int = ...,
        threads_per_core: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["core_count", b"core_count", "resource_info", b"resource_info", "threads_per_core", b"threads_per_core"]) -> None: ...

global___InstanceCpuOptions = InstanceCpuOptions

@typing_extensions.final
class InstanceCreditSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CPU_CREDITS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cpu_credits: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cpu_credits: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu_credits", b"cpu_credits", "resource_info", b"resource_info"]) -> None: ...

global___InstanceCreditSpecification = InstanceCreditSpecification

@typing_extensions.final
class InstanceElasticGpuSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___InstanceElasticGpuSpecification = InstanceElasticGpuSpecification

@typing_extensions.final
class InstanceElasticInferenceAccelerator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    count: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "resource_info", b"resource_info"]) -> None: ...

global___InstanceElasticInferenceAccelerator = InstanceElasticInferenceAccelerator

@typing_extensions.final
class InstanceHibernationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONFIGURED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    configured: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        configured: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configured", b"configured", "resource_info", b"resource_info"]) -> None: ...

global___InstanceHibernationOptions = InstanceHibernationOptions

@typing_extensions.final
class InstanceInstanceIpv6Address(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IPV6_ADDRESS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ipv6_address: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ipv6_address: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ipv6_address", b"ipv6_address", "resource_info", b"resource_info"]) -> None: ...

global___InstanceInstanceIpv6Address = InstanceInstanceIpv6Address

@typing_extensions.final
class InstanceLaunchTemplateSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LAUNCH_TEMPLATE_ID_FIELD_NUMBER: builtins.int
    LAUNCH_TEMPLATE_NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    launch_template_id: builtins.str
    launch_template_name: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        launch_template_id: builtins.str = ...,
        launch_template_name: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["launch_template_id", b"launch_template_id", "launch_template_name", b"launch_template_name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___InstanceLaunchTemplateSpecification = InstanceLaunchTemplateSpecification

@typing_extensions.final
class InstanceLicenseSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LICENSE_CONFIGURATION_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    license_configuration_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        license_configuration_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["license_configuration_arn", b"license_configuration_arn", "resource_info", b"resource_info"]) -> None: ...

global___InstanceLicenseSpecification = InstanceLicenseSpecification

@typing_extensions.final
class InstancePrivateIpAddressSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PRIMARY_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ADDRESS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    primary: builtins.bool
    private_ip_address: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        primary: builtins.bool = ...,
        private_ip_address: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["primary", b"primary", "private_ip_address", b"private_ip_address", "resource_info", b"resource_info"]) -> None: ...

global___InstancePrivateIpAddressSpecification = InstancePrivateIpAddressSpecification

@typing_extensions.final
class InstanceNetworkInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ASSOCIATE_PUBLIC_IP_ADDRESS_FIELD_NUMBER: builtins.int
    DELETE_ON_TERMINATION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DEVICE_INDEX_FIELD_NUMBER: builtins.int
    GROUP_SET_FIELD_NUMBER: builtins.int
    IPV6_ADDRESS_COUNT_FIELD_NUMBER: builtins.int
    IPV6_ADDRESSES_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACE_ID_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ADDRESS_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ADDRESSES_FIELD_NUMBER: builtins.int
    SECONDARY_PRIVATE_IP_ADDRESS_COUNT_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    associate_public_ip_address: builtins.bool
    delete_on_termination: builtins.bool
    description: builtins.str
    device_index: builtins.str
    @property
    def group_set(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    ipv6_address_count: builtins.int
    @property
    def ipv6_addresses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceInstanceIpv6Address]: ...
    network_interface_id: builtins.str
    private_ip_address: builtins.str
    @property
    def private_ip_addresses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstancePrivateIpAddressSpecification]: ...
    secondary_private_ip_address_count: builtins.int
    subnet_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        associate_public_ip_address: builtins.bool = ...,
        delete_on_termination: builtins.bool = ...,
        description: builtins.str = ...,
        device_index: builtins.str = ...,
        group_set: collections.abc.Iterable[builtins.str] | None = ...,
        ipv6_address_count: builtins.int = ...,
        ipv6_addresses: collections.abc.Iterable[global___InstanceInstanceIpv6Address] | None = ...,
        network_interface_id: builtins.str = ...,
        private_ip_address: builtins.str = ...,
        private_ip_addresses: collections.abc.Iterable[global___InstancePrivateIpAddressSpecification] | None = ...,
        secondary_private_ip_address_count: builtins.int = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["associate_public_ip_address", b"associate_public_ip_address", "delete_on_termination", b"delete_on_termination", "description", b"description", "device_index", b"device_index", "group_set", b"group_set", "ipv6_address_count", b"ipv6_address_count", "ipv6_addresses", b"ipv6_addresses", "network_interface_id", b"network_interface_id", "private_ip_address", b"private_ip_address", "private_ip_addresses", b"private_ip_addresses", "resource_info", b"resource_info", "secondary_private_ip_address_count", b"secondary_private_ip_address_count", "subnet_id", b"subnet_id"]) -> None: ...

global___InstanceNetworkInterface = InstanceNetworkInterface

@typing_extensions.final
class InstanceAssociationParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    @property
    def value(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___InstanceAssociationParameter = InstanceAssociationParameter

@typing_extensions.final
class InstanceSsmAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ASSOCIATION_PARAMETERS_FIELD_NUMBER: builtins.int
    DOCUMENT_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def association_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceAssociationParameter]: ...
    document_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        association_parameters: collections.abc.Iterable[global___InstanceAssociationParameter] | None = ...,
        document_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["association_parameters", b"association_parameters", "document_name", b"document_name", "resource_info", b"resource_info"]) -> None: ...

global___InstanceSsmAssociation = InstanceSsmAssociation

@typing_extensions.final
class InstanceVolume(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    VOLUME_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    device: builtins.str
    volume_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        device: builtins.str = ...,
        volume_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device", b"device", "resource_info", b"resource_info", "volume_id", b"volume_id"]) -> None: ...

global___InstanceVolume = InstanceVolume

@typing_extensions.final
class Instance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ADDITIONAL_INFO_FIELD_NUMBER: builtins.int
    AFFINITY_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    BLOCK_DEVICE_MAPPINGS_FIELD_NUMBER: builtins.int
    CPU_OPTIONS_FIELD_NUMBER: builtins.int
    CREDIT_SPECIFICATION_FIELD_NUMBER: builtins.int
    DISABLE_API_TERMINATION_FIELD_NUMBER: builtins.int
    EBS_OPTIMIZED_FIELD_NUMBER: builtins.int
    ELASTIC_GPU_SPECIFICATIONS_FIELD_NUMBER: builtins.int
    ELASTIC_INFERENCE_ACCELERATORS_FIELD_NUMBER: builtins.int
    HIBERNATION_OPTIONS_FIELD_NUMBER: builtins.int
    HOST_ID_FIELD_NUMBER: builtins.int
    HOST_RESOURCE_GROUP_ARN_FIELD_NUMBER: builtins.int
    IAM_INSTANCE_PROFILE_FIELD_NUMBER: builtins.int
    IMAGE_ID_FIELD_NUMBER: builtins.int
    INSTANCE_INITIATED_SHUTDOWN_BEHAVIOR_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    IPV6_ADDRESS_COUNT_FIELD_NUMBER: builtins.int
    IPV6_ADDRESSES_FIELD_NUMBER: builtins.int
    KERNEL_ID_FIELD_NUMBER: builtins.int
    KEY_NAME_FIELD_NUMBER: builtins.int
    LAUNCH_TEMPLATE_FIELD_NUMBER: builtins.int
    LICENSE_SPECIFICATIONS_FIELD_NUMBER: builtins.int
    MONITORING_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACES_FIELD_NUMBER: builtins.int
    PLACEMENT_GROUP_NAME_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ADDRESS_FIELD_NUMBER: builtins.int
    RAMDISK_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    SOURCE_DEST_CHECK_FIELD_NUMBER: builtins.int
    SSM_ASSOCIATIONS_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TENANCY_FIELD_NUMBER: builtins.int
    USER_DATA_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    PLACEMENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    additional_info: builtins.str
    affinity: builtins.str
    availability_zone: builtins.str
    @property
    def block_device_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceBlockDeviceMapping]: ...
    @property
    def cpu_options(self) -> global___InstanceCpuOptions: ...
    @property
    def credit_specification(self) -> global___InstanceCreditSpecification: ...
    disable_api_termination: builtins.bool
    ebs_optimized: builtins.bool
    @property
    def elastic_gpu_specifications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceElasticGpuSpecification]: ...
    @property
    def elastic_inference_accelerators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceElasticInferenceAccelerator]: ...
    @property
    def hibernation_options(self) -> global___InstanceHibernationOptions: ...
    host_id: builtins.str
    host_resource_group_arn: builtins.str
    iam_instance_profile: builtins.str
    image_id: builtins.str
    instance_initiated_shutdown_behavior: builtins.str
    instance_type: builtins.str
    ipv6_address_count: builtins.int
    @property
    def ipv6_addresses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceInstanceIpv6Address]: ...
    kernel_id: builtins.str
    key_name: builtins.str
    @property
    def launch_template(self) -> global___InstanceLaunchTemplateSpecification: ...
    @property
    def license_specifications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceLicenseSpecification]: ...
    monitoring: builtins.bool
    @property
    def network_interfaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceNetworkInterface]: ...
    placement_group_name: builtins.str
    private_ip_address: builtins.str
    ramdisk_id: builtins.str
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    source_dest_check: builtins.bool
    @property
    def ssm_associations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceSsmAssociation]: ...
    subnet_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    tenancy: builtins.str
    user_data: builtins.str
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InstanceVolume]: ...
    @property
    def placement(self) -> global___Placement: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        additional_info: builtins.str = ...,
        affinity: builtins.str = ...,
        availability_zone: builtins.str = ...,
        block_device_mappings: collections.abc.Iterable[global___InstanceBlockDeviceMapping] | None = ...,
        cpu_options: global___InstanceCpuOptions | None = ...,
        credit_specification: global___InstanceCreditSpecification | None = ...,
        disable_api_termination: builtins.bool = ...,
        ebs_optimized: builtins.bool = ...,
        elastic_gpu_specifications: collections.abc.Iterable[global___InstanceElasticGpuSpecification] | None = ...,
        elastic_inference_accelerators: collections.abc.Iterable[global___InstanceElasticInferenceAccelerator] | None = ...,
        hibernation_options: global___InstanceHibernationOptions | None = ...,
        host_id: builtins.str = ...,
        host_resource_group_arn: builtins.str = ...,
        iam_instance_profile: builtins.str = ...,
        image_id: builtins.str = ...,
        instance_initiated_shutdown_behavior: builtins.str = ...,
        instance_type: builtins.str = ...,
        ipv6_address_count: builtins.int = ...,
        ipv6_addresses: collections.abc.Iterable[global___InstanceInstanceIpv6Address] | None = ...,
        kernel_id: builtins.str = ...,
        key_name: builtins.str = ...,
        launch_template: global___InstanceLaunchTemplateSpecification | None = ...,
        license_specifications: collections.abc.Iterable[global___InstanceLicenseSpecification] | None = ...,
        monitoring: builtins.bool = ...,
        network_interfaces: collections.abc.Iterable[global___InstanceNetworkInterface] | None = ...,
        placement_group_name: builtins.str = ...,
        private_ip_address: builtins.str = ...,
        ramdisk_id: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        source_dest_check: builtins.bool = ...,
        ssm_associations: collections.abc.Iterable[global___InstanceSsmAssociation] | None = ...,
        subnet_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tenancy: builtins.str = ...,
        user_data: builtins.str = ...,
        volumes: collections.abc.Iterable[global___InstanceVolume] | None = ...,
        placement: global___Placement | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cpu_options", b"cpu_options", "credit_specification", b"credit_specification", "hibernation_options", b"hibernation_options", "launch_template", b"launch_template", "placement", b"placement", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_info", b"additional_info", "affinity", b"affinity", "availability_zone", b"availability_zone", "block_device_mappings", b"block_device_mappings", "cpu_options", b"cpu_options", "credit_specification", b"credit_specification", "disable_api_termination", b"disable_api_termination", "ebs_optimized", b"ebs_optimized", "elastic_gpu_specifications", b"elastic_gpu_specifications", "elastic_inference_accelerators", b"elastic_inference_accelerators", "hibernation_options", b"hibernation_options", "host_id", b"host_id", "host_resource_group_arn", b"host_resource_group_arn", "iam_instance_profile", b"iam_instance_profile", "image_id", b"image_id", "instance_initiated_shutdown_behavior", b"instance_initiated_shutdown_behavior", "instance_type", b"instance_type", "ipv6_address_count", b"ipv6_address_count", "ipv6_addresses", b"ipv6_addresses", "kernel_id", b"kernel_id", "key_name", b"key_name", "launch_template", b"launch_template", "license_specifications", b"license_specifications", "monitoring", b"monitoring", "network_interfaces", b"network_interfaces", "placement", b"placement", "placement_group_name", b"placement_group_name", "private_ip_address", b"private_ip_address", "ramdisk_id", b"ramdisk_id", "resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "security_groups", b"security_groups", "source_dest_check", b"source_dest_check", "ssm_associations", b"ssm_associations", "subnet_id", b"subnet_id", "tags", b"tags", "tenancy", b"tenancy", "user_data", b"user_data", "volumes", b"volumes"]) -> None: ...

global___Instance = Instance

@typing_extensions.final
class EC2_Instance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_FIELD_NUMBER: builtins.int
    LAUNCH_TEMPLATE_FIELD_NUMBER: builtins.int
    @property
    def instance(self) -> global___Instance: ...
    @property
    def launch_template(self) -> global___LaunchTemplate: ...
    def __init__(
        self,
        *,
        instance: global___Instance | None = ...,
        launch_template: global___LaunchTemplate | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["instance", b"instance", "launch_template", b"launch_template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance", b"instance", "launch_template", b"launch_template"]) -> None: ...

global___EC2_Instance = EC2_Instance

@typing_extensions.final
class LaunchTemplateTagSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_type: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_type: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "resource_type", b"resource_type", "tags", b"tags"]) -> None: ...

global___LaunchTemplateTagSpecification = LaunchTemplateTagSpecification

@typing_extensions.final
class LaunchTemplateEbs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    VOLUME_TYPE_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    ENCRYPTED_FIELD_NUMBER: builtins.int
    IOPS_FIELD_NUMBER: builtins.int
    VOLUME_SIZE_FIELD_NUMBER: builtins.int
    DELETE_ON_TERMINATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    snapshot_id: builtins.str
    volume_type: builtins.str
    kms_key_id: builtins.str
    encrypted: builtins.bool
    iops: builtins.int
    volume_size: builtins.int
    delete_on_termination: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        snapshot_id: builtins.str = ...,
        volume_type: builtins.str = ...,
        kms_key_id: builtins.str = ...,
        encrypted: builtins.bool = ...,
        iops: builtins.int = ...,
        volume_size: builtins.int = ...,
        delete_on_termination: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_on_termination", b"delete_on_termination", "encrypted", b"encrypted", "iops", b"iops", "kms_key_id", b"kms_key_id", "resource_info", b"resource_info", "snapshot_id", b"snapshot_id", "volume_size", b"volume_size", "volume_type", b"volume_type"]) -> None: ...

global___LaunchTemplateEbs = LaunchTemplateEbs

@typing_extensions.final
class LaunchTemplateBlockDeviceMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EBS_FIELD_NUMBER: builtins.int
    NO_DEVICE_FIELD_NUMBER: builtins.int
    VIRTUAL_NAME_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def ebs(self) -> global___LaunchTemplateEbs: ...
    no_device: builtins.str
    virtual_name: builtins.str
    device_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ebs: global___LaunchTemplateEbs | None = ...,
        no_device: builtins.str = ...,
        virtual_name: builtins.str = ...,
        device_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ebs", b"ebs", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_name", b"device_name", "ebs", b"ebs", "no_device", b"no_device", "resource_info", b"resource_info", "virtual_name", b"virtual_name"]) -> None: ...

global___LaunchTemplateBlockDeviceMapping = LaunchTemplateBlockDeviceMapping

@typing_extensions.final
class LaunchTemplateIamInstanceProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ARN_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    arn: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        arn: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arn", b"arn", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___LaunchTemplateIamInstanceProfile = LaunchTemplateIamInstanceProfile

@typing_extensions.final
class LaunchTemplateElasticGpuSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___LaunchTemplateElasticGpuSpecification = LaunchTemplateElasticGpuSpecification

@typing_extensions.final
class LaunchTemplateLaunchTemplateElasticInferenceAccelerator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    count: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "resource_info", b"resource_info"]) -> None: ...

global___LaunchTemplateLaunchTemplateElasticInferenceAccelerator = LaunchTemplateLaunchTemplateElasticInferenceAccelerator

@typing_extensions.final
class LaunchTemplatePlacement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    GROUP_NAME_FIELD_NUMBER: builtins.int
    TENANCY_FIELD_NUMBER: builtins.int
    SPREAD_DOMAIN_FIELD_NUMBER: builtins.int
    PARTITION_NUMBER_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    AFFINITY_FIELD_NUMBER: builtins.int
    HOST_ID_FIELD_NUMBER: builtins.int
    HOST_RESOURCE_GROUP_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    group_name: builtins.str
    tenancy: builtins.str
    spread_domain: builtins.str
    partition_number: builtins.int
    availability_zone: builtins.str
    affinity: builtins.str
    host_id: builtins.str
    host_resource_group_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        group_name: builtins.str = ...,
        tenancy: builtins.str = ...,
        spread_domain: builtins.str = ...,
        partition_number: builtins.int = ...,
        availability_zone: builtins.str = ...,
        affinity: builtins.str = ...,
        host_id: builtins.str = ...,
        host_resource_group_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["affinity", b"affinity", "availability_zone", b"availability_zone", "group_name", b"group_name", "host_id", b"host_id", "host_resource_group_arn", b"host_resource_group_arn", "partition_number", b"partition_number", "resource_info", b"resource_info", "spread_domain", b"spread_domain", "tenancy", b"tenancy"]) -> None: ...

global___LaunchTemplatePlacement = LaunchTemplatePlacement

@typing_extensions.final
class LaunchTemplatePrivateIpAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ADDRESS_FIELD_NUMBER: builtins.int
    PRIMARY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    private_ip_address: builtins.str
    primary: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        private_ip_address: builtins.str = ...,
        primary: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["primary", b"primary", "private_ip_address", b"private_ip_address", "resource_info", b"resource_info"]) -> None: ...

global___LaunchTemplatePrivateIpAdd = LaunchTemplatePrivateIpAdd

@typing_extensions.final
class LaunchTemplateIpv6Add(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IPV6_ADDRESS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ipv6_address: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ipv6_address: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ipv6_address", b"ipv6_address", "resource_info", b"resource_info"]) -> None: ...

global___LaunchTemplateIpv6Add = LaunchTemplateIpv6Add

@typing_extensions.final
class LaunchTemplateNetworkInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ADDRESS_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ADDRESSES_FIELD_NUMBER: builtins.int
    SECONDARY_PRIVATE_IP_ADDRESS_COUNT_FIELD_NUMBER: builtins.int
    DEVICE_INDEX_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    IPV6_ADDRESSES_FIELD_NUMBER: builtins.int
    ASSOCIATE_PUBLIC_IP_ADDRESS_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACE_ID_FIELD_NUMBER: builtins.int
    INTERFACE_TYPE_FIELD_NUMBER: builtins.int
    IPV6_ADDRESS_COUNT_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    DELETE_ON_TERMINATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    private_ip_address: builtins.str
    @property
    def private_ip_addresses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchTemplatePrivateIpAdd]: ...
    secondary_private_ip_address_count: builtins.int
    device_index: builtins.int
    subnet_id: builtins.str
    @property
    def ipv6_addresses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchTemplateIpv6Add]: ...
    associate_public_ip_address: builtins.bool
    network_interface_id: builtins.str
    interface_type: builtins.str
    ipv6_address_count: builtins.int
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    delete_on_termination: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        private_ip_address: builtins.str = ...,
        private_ip_addresses: collections.abc.Iterable[global___LaunchTemplatePrivateIpAdd] | None = ...,
        secondary_private_ip_address_count: builtins.int = ...,
        device_index: builtins.int = ...,
        subnet_id: builtins.str = ...,
        ipv6_addresses: collections.abc.Iterable[global___LaunchTemplateIpv6Add] | None = ...,
        associate_public_ip_address: builtins.bool = ...,
        network_interface_id: builtins.str = ...,
        interface_type: builtins.str = ...,
        ipv6_address_count: builtins.int = ...,
        groups: collections.abc.Iterable[builtins.str] | None = ...,
        delete_on_termination: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["associate_public_ip_address", b"associate_public_ip_address", "delete_on_termination", b"delete_on_termination", "description", b"description", "device_index", b"device_index", "groups", b"groups", "interface_type", b"interface_type", "ipv6_address_count", b"ipv6_address_count", "ipv6_addresses", b"ipv6_addresses", "network_interface_id", b"network_interface_id", "private_ip_address", b"private_ip_address", "private_ip_addresses", b"private_ip_addresses", "resource_info", b"resource_info", "secondary_private_ip_address_count", b"secondary_private_ip_address_count", "subnet_id", b"subnet_id"]) -> None: ...

global___LaunchTemplateNetworkInterface = LaunchTemplateNetworkInterface

@typing_extensions.final
class LaunchTemplateMonitoring(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "resource_info", b"resource_info"]) -> None: ...

global___LaunchTemplateMonitoring = LaunchTemplateMonitoring

@typing_extensions.final
class LaunchTemplateHibernationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CONFIGURED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    configured: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        configured: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configured", b"configured", "resource_info", b"resource_info"]) -> None: ...

global___LaunchTemplateHibernationOptions = LaunchTemplateHibernationOptions

@typing_extensions.final
class LaunchTemplateMetadataOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    HTTP_PUT_RESPONSE_HOP_LIMIT_FIELD_NUMBER: builtins.int
    HTTP_TOKENS_FIELD_NUMBER: builtins.int
    HTTP_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    http_put_response_hop_limit: builtins.int
    http_tokens: builtins.str
    http_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        http_put_response_hop_limit: builtins.int = ...,
        http_tokens: builtins.str = ...,
        http_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_endpoint", b"http_endpoint", "http_put_response_hop_limit", b"http_put_response_hop_limit", "http_tokens", b"http_tokens", "resource_info", b"resource_info"]) -> None: ...

global___LaunchTemplateMetadataOptions = LaunchTemplateMetadataOptions

@typing_extensions.final
class LaunchTemplateLicenseSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LICENSE_CONFIGURATION_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    license_configuration_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        license_configuration_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["license_configuration_arn", b"license_configuration_arn", "resource_info", b"resource_info"]) -> None: ...

global___LaunchTemplateLicenseSpecification = LaunchTemplateLicenseSpecification

@typing_extensions.final
class LaunchTemplateCpuOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    THREADS_PER_CORE_FIELD_NUMBER: builtins.int
    CORE_COUNT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    threads_per_core: builtins.int
    core_count: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        threads_per_core: builtins.int = ...,
        core_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["core_count", b"core_count", "resource_info", b"resource_info", "threads_per_core", b"threads_per_core"]) -> None: ...

global___LaunchTemplateCpuOptions = LaunchTemplateCpuOptions

@typing_extensions.final
class LaunchTemplateSpotOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SPOT_INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    INSTANCE_INTERRUPTION_BEHAVIOR_FIELD_NUMBER: builtins.int
    MAX_PRICE_FIELD_NUMBER: builtins.int
    BLOCK_DURATION_MINUTES_FIELD_NUMBER: builtins.int
    VALID_UNTIL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    spot_instance_type: builtins.str
    instance_interruption_behavior: builtins.str
    max_price: builtins.str
    block_duration_minutes: builtins.int
    valid_until: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        spot_instance_type: builtins.str = ...,
        instance_interruption_behavior: builtins.str = ...,
        max_price: builtins.str = ...,
        block_duration_minutes: builtins.int = ...,
        valid_until: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_duration_minutes", b"block_duration_minutes", "instance_interruption_behavior", b"instance_interruption_behavior", "max_price", b"max_price", "resource_info", b"resource_info", "spot_instance_type", b"spot_instance_type", "valid_until", b"valid_until"]) -> None: ...

global___LaunchTemplateSpotOptions = LaunchTemplateSpotOptions

@typing_extensions.final
class LaunchTemplateInstanceMarketOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SPOT_OPTIONS_FIELD_NUMBER: builtins.int
    MARKET_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def spot_options(self) -> global___LaunchTemplateSpotOptions: ...
    market_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        spot_options: global___LaunchTemplateSpotOptions | None = ...,
        market_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "spot_options", b"spot_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["market_type", b"market_type", "resource_info", b"resource_info", "spot_options", b"spot_options"]) -> None: ...

global___LaunchTemplateInstanceMarketOptions = LaunchTemplateInstanceMarketOptions

@typing_extensions.final
class LaunchTemplateCapacityReservationTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CAPACITY_RESERVATION_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    capacity_reservation_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        capacity_reservation_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity_reservation_id", b"capacity_reservation_id", "resource_info", b"resource_info"]) -> None: ...

global___LaunchTemplateCapacityReservationTarget = LaunchTemplateCapacityReservationTarget

@typing_extensions.final
class LaunchTemplateCapacityReservationSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CAPACITY_RESERVATION_PREFERENCE_FIELD_NUMBER: builtins.int
    CAPACITY_RESERVATION_TARGET_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    capacity_reservation_preference: builtins.str
    @property
    def capacity_reservation_target(self) -> global___LaunchTemplateCapacityReservationTarget: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        capacity_reservation_preference: builtins.str = ...,
        capacity_reservation_target: global___LaunchTemplateCapacityReservationTarget | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["capacity_reservation_target", b"capacity_reservation_target", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity_reservation_preference", b"capacity_reservation_preference", "capacity_reservation_target", b"capacity_reservation_target", "resource_info", b"resource_info"]) -> None: ...

global___LaunchTemplateCapacityReservationSpecification = LaunchTemplateCapacityReservationSpecification

@typing_extensions.final
class LaunchTemplateCreditSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CPU_CREDITS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cpu_credits: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cpu_credits: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu_credits", b"cpu_credits", "resource_info", b"resource_info"]) -> None: ...

global___LaunchTemplateCreditSpecification = LaunchTemplateCreditSpecification

@typing_extensions.final
class LaunchTemplateLaunchTemplateData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    TAG_SPECIFICATIONS_FIELD_NUMBER: builtins.int
    USER_DATA_FIELD_NUMBER: builtins.int
    BLOCK_DEVICE_MAPPINGS_FIELD_NUMBER: builtins.int
    IAM_INSTANCE_PROFILE_FIELD_NUMBER: builtins.int
    KERNEL_ID_FIELD_NUMBER: builtins.int
    EBS_OPTIMIZED_FIELD_NUMBER: builtins.int
    ELASTIC_GPU_SPECIFICATIONS_FIELD_NUMBER: builtins.int
    ELASTIC_INFERENCE_ACCELERATORS_FIELD_NUMBER: builtins.int
    PLACEMENT_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACES_FIELD_NUMBER: builtins.int
    IMAGE_ID_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    MONITORING_FIELD_NUMBER: builtins.int
    HIBERNATION_OPTIONS_FIELD_NUMBER: builtins.int
    METADATA_OPTIONS_FIELD_NUMBER: builtins.int
    LICENSE_SPECIFICATIONS_FIELD_NUMBER: builtins.int
    INSTANCE_INITIATED_SHUTDOWN_BEHAVIOR_FIELD_NUMBER: builtins.int
    CPU_OPTIONS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    KEY_NAME_FIELD_NUMBER: builtins.int
    DISABLE_API_TERMINATION_FIELD_NUMBER: builtins.int
    INSTANCE_MARKET_OPTIONS_FIELD_NUMBER: builtins.int
    RAM_DISK_ID_FIELD_NUMBER: builtins.int
    CAPACITY_RESERVATION_SPECIFICATION_FIELD_NUMBER: builtins.int
    CREDIT_SPECIFICATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tag_specifications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchTemplateTagSpecification]: ...
    user_data: builtins.str
    @property
    def block_device_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchTemplateBlockDeviceMapping]: ...
    @property
    def iam_instance_profile(self) -> global___LaunchTemplateIamInstanceProfile: ...
    kernel_id: builtins.str
    ebs_optimized: builtins.bool
    @property
    def elastic_gpu_specifications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchTemplateElasticGpuSpecification]: ...
    @property
    def elastic_inference_accelerators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchTemplateLaunchTemplateElasticInferenceAccelerator]: ...
    @property
    def placement(self) -> global___LaunchTemplatePlacement: ...
    @property
    def network_interfaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchTemplateNetworkInterface]: ...
    image_id: builtins.str
    instance_type: builtins.str
    @property
    def monitoring(self) -> global___LaunchTemplateMonitoring: ...
    @property
    def hibernation_options(self) -> global___LaunchTemplateHibernationOptions: ...
    @property
    def metadata_options(self) -> global___LaunchTemplateMetadataOptions: ...
    @property
    def license_specifications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchTemplateLicenseSpecification]: ...
    instance_initiated_shutdown_behavior: builtins.str
    @property
    def cpu_options(self) -> global___LaunchTemplateCpuOptions: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    key_name: builtins.str
    disable_api_termination: builtins.bool
    @property
    def instance_market_options(self) -> global___LaunchTemplateInstanceMarketOptions: ...
    ram_disk_id: builtins.str
    @property
    def capacity_reservation_specification(self) -> global___LaunchTemplateCapacityReservationSpecification: ...
    @property
    def credit_specification(self) -> global___LaunchTemplateCreditSpecification: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        tag_specifications: collections.abc.Iterable[global___LaunchTemplateTagSpecification] | None = ...,
        user_data: builtins.str = ...,
        block_device_mappings: collections.abc.Iterable[global___LaunchTemplateBlockDeviceMapping] | None = ...,
        iam_instance_profile: global___LaunchTemplateIamInstanceProfile | None = ...,
        kernel_id: builtins.str = ...,
        ebs_optimized: builtins.bool = ...,
        elastic_gpu_specifications: collections.abc.Iterable[global___LaunchTemplateElasticGpuSpecification] | None = ...,
        elastic_inference_accelerators: collections.abc.Iterable[global___LaunchTemplateLaunchTemplateElasticInferenceAccelerator] | None = ...,
        placement: global___LaunchTemplatePlacement | None = ...,
        network_interfaces: collections.abc.Iterable[global___LaunchTemplateNetworkInterface] | None = ...,
        image_id: builtins.str = ...,
        instance_type: builtins.str = ...,
        monitoring: global___LaunchTemplateMonitoring | None = ...,
        hibernation_options: global___LaunchTemplateHibernationOptions | None = ...,
        metadata_options: global___LaunchTemplateMetadataOptions | None = ...,
        license_specifications: collections.abc.Iterable[global___LaunchTemplateLicenseSpecification] | None = ...,
        instance_initiated_shutdown_behavior: builtins.str = ...,
        cpu_options: global___LaunchTemplateCpuOptions | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        key_name: builtins.str = ...,
        disable_api_termination: builtins.bool = ...,
        instance_market_options: global___LaunchTemplateInstanceMarketOptions | None = ...,
        ram_disk_id: builtins.str = ...,
        capacity_reservation_specification: global___LaunchTemplateCapacityReservationSpecification | None = ...,
        credit_specification: global___LaunchTemplateCreditSpecification | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["capacity_reservation_specification", b"capacity_reservation_specification", "cpu_options", b"cpu_options", "credit_specification", b"credit_specification", "hibernation_options", b"hibernation_options", "iam_instance_profile", b"iam_instance_profile", "instance_market_options", b"instance_market_options", "metadata_options", b"metadata_options", "monitoring", b"monitoring", "placement", b"placement", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_device_mappings", b"block_device_mappings", "capacity_reservation_specification", b"capacity_reservation_specification", "cpu_options", b"cpu_options", "credit_specification", b"credit_specification", "disable_api_termination", b"disable_api_termination", "ebs_optimized", b"ebs_optimized", "elastic_gpu_specifications", b"elastic_gpu_specifications", "elastic_inference_accelerators", b"elastic_inference_accelerators", "hibernation_options", b"hibernation_options", "iam_instance_profile", b"iam_instance_profile", "image_id", b"image_id", "instance_initiated_shutdown_behavior", b"instance_initiated_shutdown_behavior", "instance_market_options", b"instance_market_options", "instance_type", b"instance_type", "kernel_id", b"kernel_id", "key_name", b"key_name", "license_specifications", b"license_specifications", "metadata_options", b"metadata_options", "monitoring", b"monitoring", "network_interfaces", b"network_interfaces", "placement", b"placement", "ram_disk_id", b"ram_disk_id", "resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "security_groups", b"security_groups", "tag_specifications", b"tag_specifications", "user_data", b"user_data"]) -> None: ...

global___LaunchTemplateLaunchTemplateData = LaunchTemplateLaunchTemplateData

@typing_extensions.final
class Placement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    availability_zone: builtins.str
    def __init__(
        self,
        *,
        availability_zone: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["availability_zone", b"availability_zone"]) -> None: ...

global___Placement = Placement

@typing_extensions.final
class LaunchTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LAUNCH_TEMPLATE_NAME_FIELD_NUMBER: builtins.int
    LAUNCH_TEMPLATE_DATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    launch_template_name: builtins.str
    @property
    def launch_template_data(self) -> global___LaunchTemplateLaunchTemplateData: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        launch_template_name: builtins.str = ...,
        launch_template_data: global___LaunchTemplateLaunchTemplateData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["launch_template_data", b"launch_template_data", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["launch_template_data", b"launch_template_data", "launch_template_name", b"launch_template_name", "resource_info", b"resource_info"]) -> None: ...

global___LaunchTemplate = LaunchTemplate



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_load_balancer_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_compute_backend_pb2 as gcp_dot_gcp__compute__backend__pb2
from oak9.tython.models.gcp import gcp_compute_forwarding_pb2 as gcp_dot_gcp__compute__forwarding__pb2
from oak9.tython.models.gcp import gcp_compute_global_pb2 as gcp_dot_gcp__compute__global__pb2
from oak9.tython.models.gcp import gcp_compute_health_pb2 as gcp_dot_gcp__compute__health__pb2
from oak9.tython.models.gcp import gcp_compute_http_pb2 as gcp_dot_gcp__compute__http__pb2
from oak9.tython.models.gcp import gcp_compute_https_pb2 as gcp_dot_gcp__compute__https__pb2
from oak9.tython.models.gcp import gcp_compute_region_pb2 as gcp_dot_gcp__compute__region__pb2
from oak9.tython.models.gcp import gcp_compute_ssl_pb2 as gcp_dot_gcp__compute__ssl__pb2
from oak9.tython.models.gcp import gcp_compute_target_pb2 as gcp_dot_gcp__compute__target__pb2
from oak9.tython.models.gcp import gcp_compute_url_pb2 as gcp_dot_gcp__compute__url__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)gcp/gcp_google_load_balancer_bundle.proto\x12+oak9.tython.gcp.google_load_balancer_bundle\x1a\x13shared/shared.proto\x1a\x1dgcp/gcp_compute_backend.proto\x1a gcp/gcp_compute_forwarding.proto\x1a\x1cgcp/gcp_compute_global.proto\x1a\x1cgcp/gcp_compute_health.proto\x1a\x1agcp/gcp_compute_http.proto\x1a\x1bgcp/gcp_compute_https.proto\x1a\x1cgcp/gcp_compute_region.proto\x1a\x19gcp/gcp_compute_ssl.proto\x1a\x1cgcp/gcp_compute_target.proto\x1a\x19gcp/gcp_compute_url.proto\"\xbc\x11\n\x12GoogleLoadBalancer\x12U\n\x16\x63ompute_backend_bucket\x18\x01 \x01(\x0b\x32\x35.oak9.tython.gcp.compute_backend.ComputeBackendBucket\x12p\n%compute_backend_bucket_signed_url_key\x18\x02 \x01(\x0b\x32\x41.oak9.tython.gcp.compute_backend.ComputeBackendBucketSignedUrlKey\x12W\n\x17\x63ompute_backend_service\x18\x03 \x01(\x0b\x32\x36.oak9.tython.gcp.compute_backend.ComputeBackendService\x12r\n&compute_backend_service_signed_url_key\x18\x04 \x01(\x0b\x32\x42.oak9.tython.gcp.compute_backend.ComputeBackendServiceSignedUrlKey\x12Z\n\x17\x63ompute_forwarding_rule\x18\x05 \x01(\x0b\x32\x39.oak9.tython.gcp.compute_forwarding.ComputeForwardingRule\x12\x63\n\x1e\x63ompute_global_forwarding_rule\x18\x06 \x01(\x0b\x32;.oak9.tython.gcp.compute_global.ComputeGlobalForwardingRule\x12P\n\x14\x63ompute_health_check\x18\x07 \x01(\x0b\x32\x32.oak9.tython.gcp.compute_health.ComputeHealthCheck\x12W\n\x19\x63ompute_http_health_check\x18\x08 \x01(\x0b\x32\x34.oak9.tython.gcp.compute_http.ComputeHttpHealthCheck\x12Z\n\x1a\x63ompute_https_health_check\x18\t \x01(\x0b\x32\x36.oak9.tython.gcp.compute_https.ComputeHttpsHealthCheck\x12\x63\n\x1e\x63ompute_region_backend_service\x18\n \x01(\x0b\x32;.oak9.tython.gcp.compute_region.ComputeRegionBackendService\x12]\n\x1b\x63ompute_region_health_check\x18\x0b \x01(\x0b\x32\x38.oak9.tython.gcp.compute_region.ComputeRegionHealthCheck\x12\x63\n\x1e\x63ompute_region_ssl_certificate\x18\x0c \x01(\x0b\x32;.oak9.tython.gcp.compute_region.ComputeRegionSslCertificate\x12\x66\n compute_region_target_http_proxy\x18\r \x01(\x0b\x32<.oak9.tython.gcp.compute_region.ComputeRegionTargetHttpProxy\x12h\n!compute_region_target_https_proxy\x18\x0e \x01(\x0b\x32=.oak9.tython.gcp.compute_region.ComputeRegionTargetHttpsProxy\x12S\n\x16\x63ompute_region_url_map\x18\x0f \x01(\x0b\x32\x33.oak9.tython.gcp.compute_region.ComputeRegionUrlMap\x12S\n\x17\x63ompute_ssl_certificate\x18\x10 \x01(\x0b\x32\x32.oak9.tython.gcp.compute_ssl.ComputeSslCertificate\x12I\n\x12\x63ompute_ssl_policy\x18\x11 \x01(\x0b\x32-.oak9.tython.gcp.compute_ssl.ComputeSslPolicy\x12Y\n\x19\x63ompute_target_grpc_proxy\x18\x12 \x01(\x0b\x32\x36.oak9.tython.gcp.compute_target.ComputeTargetGrpcProxy\x12Y\n\x19\x63ompute_target_http_proxy\x18\x13 \x01(\x0b\x32\x36.oak9.tython.gcp.compute_target.ComputeTargetHttpProxy\x12[\n\x1a\x63ompute_target_https_proxy\x18\x14 \x01(\x0b\x32\x37.oak9.tython.gcp.compute_target.ComputeTargetHttpsProxy\x12N\n\x13\x63ompute_target_pool\x18\x15 \x01(\x0b\x32\x31.oak9.tython.gcp.compute_target.ComputeTargetPool\x12W\n\x18\x63ompute_target_ssl_proxy\x18\x16 \x01(\x0b\x32\x35.oak9.tython.gcp.compute_target.ComputeTargetSslProxy\x12W\n\x18\x63ompute_target_tcp_proxy\x18\x17 \x01(\x0b\x32\x35.oak9.tython.gcp.compute_target.ComputeTargetTcpProxy\x12\x43\n\x0f\x63ompute_url_map\x18\x18 \x01(\x0b\x32*.oak9.tython.gcp.compute_url.ComputeUrlMapb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_load_balancer_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLELOADBALANCER._serialized_start=408
  _GOOGLELOADBALANCER._serialized_end=2644
# @@protoc_insertion_point(module_scope)
